# Generated by Django 4.0.4 on 2022-05-13 12:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_reviews', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='reviews',
            name='validate',
            field=models.BooleanField(blank=True, default=False, verbose_name='Validate'),
        ),
    ]
